Rdocumentation
powered by
Learn R Programming
timecourse (version 1.44.0)
ot.helmert: Helmert orthogonal transformation
Description
Computes the Helmert orthogonal transformation matrix.
Usage
ot.helmert(k)
Arguments
k
a positive integer giving the number of time points.
Value
a numeric matrix.
Details
This function is for internal use only and is not to be called by the user.